# Banco de Usuarios
**bancodeusuarios** é um simples pacote para gerenciar o cadastro, armazenamento e consulta de usuários em um sistema.

## Dependências
**Python 3.6** ou posterior

## Começando o uso
Você vai precisar instalar o pacote **bancodeusuarios**, para isso basta executar:
```
pip install bancodeusuarios
```

## Função
* `interagir()` - Coleta o CPF, Nome e o Endereço do usuario.
* `armazenar()` - Armazena as informações coletadas em um arquivo .txt.
* `consultar()` - Consulta o arquivo de texto e exibe as informações referentes ao CPF informado.

## Demo
O pacote ainda conta com um arquivo `main.py` que demonstra o funcionamento do mesmo.